==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/CastCheckTag.h <==
// public class soot.jimple.toolkits.pointer.CastCheckTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 42add73807ce705a soot_jimple_toolkits_pointer_CastCheckTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_CastCheckTag_H_
#define _JC_soot_jimple_toolkits_pointer_CastCheckTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_refs	_jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$refs	_jc_soot_jimple_toolkits_pointer_CastCheckTag$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$nonrefs	_jc_soot_jimple_toolkits_pointer_CastCheckTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object	_jc_soot_jimple_toolkits_pointer_CastCheckTag$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vmethods	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtable	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_CastCheckTag$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *, jboolean);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_CastCheckTag$method$canEliminateCheck$b591073642c999db(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_CastCheckTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *);
extern _jc_byte_array *_jc_soot_jimple_toolkits_pointer_CastCheckTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_CastCheckTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckTag$method_info$canEliminateCheck$b591073642c999db;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vmethods {
	jboolean	(*canEliminateCheck$b591073642c999db)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vmethods	soot_jimple_toolkits_pointer_CastCheckTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$refs {
    _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_refs	soot_jimple_toolkits_pointer_CastCheckTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_nonrefs {
	jboolean	eliminateCheck;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_nonrefs	soot_jimple_toolkits_pointer_CastCheckTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object {
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype _jc_soot_jimple_toolkits_pointer_CastCheckTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_CastCheckTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_CastCheckTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_CastCheckTag_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/CastCheckTag.h <==
// public class soot.jimple.toolkits.pointer.CastCheckTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 42add73807ce705a soot_jimple_toolkits_pointer_CastCheckTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_CastCheckTag_H_
#define _JC_soot_jimple_toolkits_pointer_CastCheckTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_refs	_jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$refs	_jc_soot_jimple_toolkits_pointer_CastCheckTag$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$nonrefs	_jc_soot_jimple_toolkits_pointer_CastCheckTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object	_jc_soot_jimple_toolkits_pointer_CastCheckTag$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vmethods	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtable	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_CastCheckTag$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_CastCheckTag$method$canEliminateCheck$b591073642c999db(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_CastCheckTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_jimple_toolkits_pointer_CastCheckTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_CastCheckTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckTag$method_info$canEliminateCheck$b591073642c999db;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vmethods {
	jboolean	(*canEliminateCheck$b591073642c999db)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vmethods	soot_jimple_toolkits_pointer_CastCheckTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$refs {
    _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_refs	soot_jimple_toolkits_pointer_CastCheckTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_nonrefs {
	jboolean	eliminateCheck;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_CastCheckTag$sub_nonrefs	soot_jimple_toolkits_pointer_CastCheckTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_CastCheckTag$object {
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_CastCheckTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_CastCheckTag$vtype _jc_soot_jimple_toolkits_pointer_CastCheckTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_CastCheckTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_CastCheckTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_CastCheckTag_H_ */
